@@ -15,7 +15,10 @@ from zim.gui.applications import *
 from zim.notebook import Path
 from zim.fs import Dir, TmpFile
 
+THUMB_SIZE_NORMAL = 128
 
+
+@tests.skipIf(os.name == 'nt', 'Skip for windows')
 @tests.slowTest
 class TestXDGMimeInfo(tests.TestCase):
 
@@ -23,7 +26,7 @@ class TestXDGMimeInfo(tests.TestCase):
 		dir = Dir('./data/pixmaps')
 		for i, filename in enumerate(dir.list()):
 			file = dir.file(filename)
-			icon = get_mime_icon(file, THUMB_SIZE_NORMAL)
+			icon = get_mime_icon(file, 128)
 			self.assertIsInstance(icon, gtk.gdk.Pixbuf)
 			desc = get_mime_description(file.get_mimetype())
 			self.assertIsInstance(desc, basestring)
@@ -284,6 +287,7 @@ class TestCustomTools(tests.TestCase):
 		# %f for source file as tmp file current page
 		# %d for attachment directory
 		# %s for real source file (if any)
+		# %p for the page name
 		# %n for notebook location (file or directory)
 		# %D for document root
 		# %t for selected text or word under cursor
@@ -307,7 +311,8 @@ class TestCustomTools(tests.TestCase):
 		for cmd, wanted in (
 			('foo %f', ('foo', tmpfile)),
 			('foo %d', ('foo', dir.subdir('Test/Foo').path)),
-			('foo %s', ('foo', '')), # no file source
+			('foo %s', ('foo', page.source.path)),
+			('foo %p', ('foo', 'Test:Foo')),
 			('foo %n', ('foo', dir.path)),
 			('foo %D', ('foo', '')), # no document root
 			('foo %t', ('foo', 'FooBar')),
@@ -421,4 +426,3 @@ class StubPageView(object):
 if __name__ == '__main__':
 	import unittest
 	unittest.main()
-
