@@ -64,7 +64,10 @@ class TestPluginClasses(tests.TestCase):
 			self.assertTrue(file.exists(), 'Missing file: %s' % file)
 
 			manual = file.read()
+			ignore = getattr(klass, 'hide_preferences', [])
 			for pref in klass.plugin_preferences:
+				if pref[0] in ignore:
+					continue
 				label = pref[2]
 				if '\n' in label:
 					label, x = label.split('\n', 1)
@@ -159,8 +162,8 @@ class TestPlugins(tests.TestCase):
 		for obj in (
 			notebook,
 			notebook.index,
-			ui.mainwindow,
-			ui.mainwindow.pageview,
+			ui._mainwindow,				# XXX
+			ui._mainwindow.pageview,	# XXX
 			dialog,
 		):
 			manager.extend(obj)
@@ -178,3 +181,16 @@ class TestPlugins(tests.TestCase):
 		self.assertTrue(len(manager) == 0)
 
 
+
+from tests.pageview import setUpPageView
+from zim.config import ConfigDict
+
+class MockWindow(tests.MockObject):
+
+	def __init__(self):
+		tests.MockObject.__init__(self)
+
+		self.pageview = setUpPageView()
+		self.uimanager = tests.MockObject()
+		self.ui = tests.MockObject()
+		self.ui.uistate = ConfigDict()
