@@ -90,13 +90,14 @@ class TestMainWindowExtension(tests.TestCase):
 		dir = get_tmp_dir('versioncontrol_TestMainWindowExtension')
 		notebook = tests.new_files_notebook(dir)
 		ui = setupGtkInterface(self, notebook=notebook)
+		mainwindow = ui._mainwindow # XXX
 		plugin.extend(notebook)
-		plugin.extend(ui.mainwindow)
+		plugin.extend(mainwindow)
 
-		notebook_ext = plugin.get_extension(NotebookExtension)
+		notebook_ext = plugin.get_extension(notebook, NotebookExtension)
 		self.assertIsInstance(notebook_ext, NotebookExtension)
 
-		window_ext = plugin.get_extension(MainWindowExtension)
+		window_ext = plugin.get_extension(mainwindow, MainWindowExtension)
 		self.assertIsInstance(window_ext, MainWindowExtension)
 
 		## init & save version
@@ -189,6 +190,7 @@ class TestBazaar(VersionControlBackendTests, tests.TestCase):
 		'''Test Bazaar version control'''
 		root = get_tmp_dir('versioncontrol_TestBazaar')
 		vcs = VCS.create(VCS.BZR, root, root)
+		self.addCleanup(vcs.disconnect_all)
 		vcs.init()
 
 		#~ for notebookdir in (root, root.subdir('foobar')):
@@ -322,6 +324,7 @@ class TestGit(VersionControlBackendTests, tests.TestCase):
 		'''Test Git version control'''
 		root = get_tmp_dir('versioncontrol_TestGit')
 		vcs = VCS.create(VCS.GIT, root, root)
+		self.addCleanup(vcs.disconnect_all)
 		vcs.init()
 
 		#~ for notebookdir in (root, root.subdir('foobar')):
@@ -332,11 +335,11 @@ class TestGit(VersionControlBackendTests, tests.TestCase):
 		subdir = root.subdir('foo/bar')
 		file = subdir.file('baz.txt')
 		file.write('foo\nbar\n')
+		vcs.stage(file)
 		self.assertEqual(''.join(vcs.get_status(porcelain=True)),
 			'A  .gitignore\n'
 			'A  foo/bar/baz.txt\n'
 		)
-		vcs.update_staging()
 		vcs.commit('test 1')
 #[master 0f4132e] test 1
 # 1 files changed, 3 insertions(+), 0 deletions(-)
@@ -347,12 +350,12 @@ class TestGit(VersionControlBackendTests, tests.TestCase):
 
 		file = subdir.file('bar.txt')
 		file.write('second\ntest\n')
+		vcs.stage(file)
 
 		self.assertEqual(''.join(vcs.get_status(porcelain=True)),
 			'A  foo/bar/bar.txt\n'
 		)
 
-		vcs.update_staging()
 		vcs.commit('test 2')
 #[master dbebdf1] test 2
 # 0 files changed, 0 insertions(+), 0 deletions(-)
@@ -499,6 +502,7 @@ class TestMercurial(VersionControlBackendTests, tests.TestCase):
 		'''Test Mercurial version control'''
 		root = get_tmp_dir('versioncontrol_TestMercurial')
 		vcs = VCS.create(VCS.HG, root, root)
+		self.addCleanup(vcs.disconnect_all)
 		vcs.init()
 
 		#~ for notebookdir in (root, root.subdir('foobar')):
@@ -621,6 +625,7 @@ class TestFossil(VersionControlBackendTests, tests.TestCase):
 		'''Test Fossil version control'''
 		root = get_tmp_dir('versioncontrol_TestFossil')
 		vcs = VCS.create(VCS.FOSSIL, root, root)
+		self.addCleanup(vcs.disconnect_all)
 		vcs.init()
 
 		subdir = root.subdir('foo/bar')
@@ -630,7 +635,6 @@ class TestFossil(VersionControlBackendTests, tests.TestCase):
 		self.assertEqual(''.join(vcs.get_status()),
 			'ADDED      foo/bar/baz.txt\n'
 		)
-		vcs.update_staging()
 		vcs.commit('test 1')
 
 		file = subdir.file('bar.txt')
@@ -641,7 +645,6 @@ class TestFossil(VersionControlBackendTests, tests.TestCase):
 			'ADDED      foo/bar/bar.txt\n'
 		)
 
-		vcs.update_staging()
 		vcs.commit('test 2')
 
 		versions = vcs.list_versions()
