@@ -21,7 +21,10 @@ except:
 # Win32: must setup log file or it tries to write to $PROGRAMFILES
 # See http://www.py2exe.org/index.cgi/StderrLog
 # If startup is OK, this will be overruled in zim/main with per user log file
-if os.name == "nt" and sys.argv[0].endswith('.exe'):
+if os.name == "nt" and (
+	sys.argv[0].endswith('.exe')
+	or sys.executable.endswith('pythonw.exe')
+):
 	import tempfile
 	dir = tempfile.gettempdir()
 	if not os.path.isdir(dir):
@@ -31,7 +34,8 @@ if os.name == "nt" and sys.argv[0].endswith('.exe'):
 	sys.stderr = err_stream
 
 # Preliminary initialization of logging because modules can throw warnings at import
-logging.basicConfig(level=logging.INFO, format='%(levelname)s: %(message)s')
+logging.basicConfig(level=logging.WARN, format='%(levelname)s: %(message)s')
+logging.captureWarnings(True)
 
 # Try importing our modules
 try:
